@@ -12,10 +12,14 @@ package javax.portlet.faces;
 
 import javax.portlet.ActionRequest;
 import javax.portlet.ActionResponse;
+import javax.portlet.EventRequest;
+import javax.portlet.EventResponse;
 import javax.portlet.PortletConfig;
 import javax.portlet.PortletException;
 import javax.portlet.RenderRequest;
 import javax.portlet.RenderResponse;
+import javax.portlet.ResourceRequest;
+import javax.portlet.ResourceResponse;
 import javax.portlet.UnavailableException;
 
 /**
@@ -86,21 +90,7 @@ Bridge
   // Following are the names of context init attributes set by the portlet to control
   // Bridge behavior. For the GenericFacesPortlet, the values for these come from 
   // portlet initialization parameters in the portlet.xml
-
-  /** A PortletContext attribute that a portlet can set prior
-   * to calling the bridge's init() method to configure the bridge to preserve
-   * action parameters received by this portlet along with bridge's request scope so
-   * that they may be restored and acessed in subsequent renders.  If "true", the
-   * action parameters are preserved.  If "false", they are not preserved.  The bridge
-   * default is "false".<br>
-   *
-   * As this attribute is scoped to a specific portlet in an application-wide context
-   * the attribute name must be include the portlet name as follows:
-   * BRIDGE_PACKAGE_PREFIX + context.getPortletName() + preserveActionParams
-   */
-  public static final String PRESERVE_ACTION_PARAMS = "preserveActionParams";
-
-
+  
   /** A PortletContext attribute that a portlet can set prior
    * to calling the bridge's init() method to configure the bridge to exclude
    * specific attributes from its bridge request scope. Value is a comma delimited
@@ -127,6 +117,60 @@ Bridge
    */
   public static final String DEFAULT_VIEWID_MAP = "defaultViewIdMap";
 
+
+  /** A PortletContext attribute that a portlet can set prior
+   * to calling the bridge's init() method to configure the bridge to preserve
+   * action parameters received by this portlet along with bridge's request scope so
+   * that they may be restored and acessed in subsequent renders.  If "true", the
+   * action parameters are preserved.  If "false", they are not preserved.  The bridge
+   * default is "false".<br>
+   *
+   * As this attribute is scoped to a specific portlet in an application-wide context
+   * the attribute name must be include the portlet name as follows:
+   * BRIDGE_PACKAGE_PREFIX + context.getPortletName() + preserveActionParams
+   */
+  public static final String PRESERVE_ACTION_PARAMS = "preserveActionParams";
+  
+  /** A PortletContext attribute that a portlet can set prior
+   * to calling the bridge's init() method to configure the bridge to use/call
+   * the associated eventHandler when processing an event. Value is an instance of
+   * <code>BridgeEventHandler</code>.
+   *
+   * As this attribute is scoped to a specific portlet in an application-wide context
+   * the attribute name must be include the portlet name as follows:
+   * BRIDGE_PACKAGE_PREFIX + context.getPortletName() + bridgeEventHandler
+   */
+  public static final String BRIDGE_EVENT_HANDLER = "bridgeEventHandler";
+  
+  /** A PortletContext attribute that a portlet can set prior
+   * to calling the bridge's init() method to configure the bridge to use/call
+   * the associated publicRenderParameterHandler.  This handler is used to
+   * process updates that result from public render parameter changes passed in 
+   * a request.  The bridge first pushs all the public render parameter values into the models and
+   * then calls this handler's processUpdates method.  The handler can then compute
+   * further model changes based on the changes. Value is an instance of
+   * <code>BridgePublicRenderParameterHandler</code>.
+   *
+   * As this attribute is scoped to a specific portlet in an application-wide context
+   * the attribute name must be include the portlet name as follows:
+   * BRIDGE_PACKAGE_PREFIX + context.getPortletName() + bridgeEventHandler
+   */
+  public static final String BRIDGE_PUBLIC_RENDER_PARAMETER_HANDLER = "bridgePublicRenderParameterHandler";
+  
+  
+  /** A PortletContext attribute that a portlet can set prior
+   * to calling the bridge's init() method to configure the bridge to default
+   * the renderKitId used for rendering this portlet to the named Id.  In Faces, the 
+   * default renderKitId is set in the faces-config.xml and is application wide.  In 1.2
+   * this can be overidden by a specially named request parameter. To allow differing portlets
+   * in the same app to use different default render kits, without having to add this 
+   * parameter, the portlet can set this attribute prior to the bridge init().  The bridge 
+   * will recognize this configuration value and on each request add the special faces
+   * request parameter to the request (if its not already present).
+   */
+  public static final String DEFAULT_RENDERKIT_ID = "defaultRenderKitId";
+ 
+
   // The following are request attributes a portlet can set to control the request
   // processing of the bridge.  
 
@@ -187,6 +231,13 @@ Bridge
    * this url unchanged.
    */
   public static final String DIRECT_LINK = BRIDGE_PACKAGE_PREFIX + "DirectLink";
+  
+  /**
+   * Special token parameter in the url passed to the bridge's ExternalContext.encodeResourceURL()
+   * that it recognizes as an indication that this resource should be handled in protocol.
+   */
+  public static final String IN_PROTOCOL_RESOURCE_LINK = 
+    BRIDGE_PACKAGE_PREFIX + "InProtocolResourceLink";
 
   /**
    * Special token parameter in the url passed to the bridge's ExternalContext.encodeResourceURL()
@@ -301,6 +352,7 @@ Bridge
    */
   public static final String FACES_VIEW_PATH_PARAMETER = "_jsfBridgeViewPath";
 
+
   
   /** Special value recognized during <code>encodeActionURL</code> of a portlet: url containing either
    * the <code>_jsfBridgeViewId</code> or <code>_jsfBridgeViewPath</code> parameter. 
@@ -311,6 +363,7 @@ Bridge
    */
   public static final String FACES_USE_CURRENT_VIEW_PARAMETER = "_jsfBridgeCurrentView";
 
+
   /** Enumeration whose values describe the current portlet phase the bridge
    * is executing Faces within.
    */
@@ -318,6 +371,8 @@ Bridge
   {
     ACTION_PHASE,
     RENDER_PHASE,
+    EVENT_PHASE,
+    RESOURCE_PHASE,
     ;
   }
 
@@ -406,6 +461,23 @@ Bridge
                              ActionResponse response) throws BridgeDefaultViewNotSpecifiedException, 
                                                              BridgeUninitializedException, 
                                                              BridgeException;
+  
+  /**
+   * Called by the portlet when it wants the bridge to process an event request.
+   * 
+   * @param request
+   *          the request object.
+   * @param response
+   *          the response object.
+   * @throws BridgeUninitializedException
+   *           thrown if the bridge is not initialized.      
+   * @throws BridgeException
+   *           all other internal exceptions are converted to a BridgeException.
+   */
+  public void doFacesRequest(EventRequest request, 
+                             EventResponse response) throws BridgeUninitializedException, 
+                                                               BridgeException;
+
 
   /**
    * Called by the portlet when it wants the bridge to process a render request.
@@ -427,6 +499,23 @@ Bridge
                                                              BridgeUninitializedException, 
                                                              BridgeException;
 
+  /**
+   * Called by the portlet when it wants the bridge to process an in-protocol
+   * resource request.
+   * 
+   * @param request
+   *          the request object.
+   * @param response
+   *          the response object.
+   * @throws BridgeUninitializedException
+   *           thrown if the bridge is not initialized.      
+   * @throws BridgeException
+   *           all other internal exceptions are converted to a BridgeException.
+   */
+  public void doFacesRequest(ResourceRequest request, 
+                             ResourceResponse response) throws BridgeUninitializedException, 
+                                                               BridgeException;
+
   /**
    * Called by the portlet to take the bridge out of service. Once out of service, the bridge must
    * be reinitialized before processing any further requests.
